==> haskell-conduit-1.3.1-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.3.1
id: conduit-1.3.1-1ncJAGOGfjaJsj5t5Gnhwi
key: conduit-1.3.1-1ncJAGOGfjaJsj5t5Gnhwi
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.
    .
    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).
    .
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
category: Data, Conduit
abi: d6a3cd3dadabfcaa69d7b8bcbf91a2c5
exposed: True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit Data.Conduit.Combinators.Unqualified
                Data.Streaming.FileRead Data.Streaming.Filesystem
import-dirs: /usr/lib/ghc-8.6.3/site-local/conduit-1.3.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/conduit-1.3.1
hs-libraries: HSconduit-1.3.1-1ncJAGOGfjaJsj5t5Gnhwi
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    exceptions-0.10.0-29UXSV5bKJ4B0H4dLl5Nff filepath-1.4.2.1
    mono-traversable-1.0.11.0-uX7LqThAkM3bJ2tq1doA mtl-2.2.2
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
    resourcet-1.2.2-5i3IrLQ8cCMFRKp3qE5jS8 text-1.2.3.1
    transformers-0.5.5.0 unix-2.7.2.2
    unliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-1.3.1-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.3.1
id: conduit-1.3.1-JmMdk65SNka3dWWZlerpD5
key: conduit-1.3.1-JmMdk65SNka3dWWZlerpD5
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.
    .
    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).
    .
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
category: Data, Conduit
abi: 70cc9544fc544dfdc81ea67b6ca6b50c
exposed: True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit Data.Conduit.Combinators.Unqualified
                Data.Streaming.FileRead Data.Streaming.Filesystem
import-dirs: /usr/lib/ghc-8.6.3/site-local/conduit-1.3.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/conduit-1.3.1
hs-libraries: HSconduit-1.3.1-JmMdk65SNka3dWWZlerpD5
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    exceptions-0.10.0-29UXSV5bKJ4B0H4dLl5Nff filepath-1.4.2.1
    mono-traversable-1.0.11.0-ExTxb0L2As9AHwc4AykLPE mtl-2.2.2
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
    resourcet-1.2.2-Lrcu6EHQLGUJY1Qaiy4SUl text-1.2.3.1
    transformers-0.5.5.0 unix-2.7.2.2
    unliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
